==> ssp-center-api-0.5.41-20190729.021326-2-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ReqIdAndType.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;

/**
 * 公用查询类
 *
 * @author xuyenan
 * @createTime 2016/10/31
 */
public class ReqIdAndType implements Serializable {

    /**
     * 活动来源 0-兑吧
     */
    public static final int REQ_ACT_SOURCE_DUIBA = 0;
    /**
     * 活动来源 1-推啊
     */
    public static final int REQ_ACT_SOURCE_TUIA = 1;
    /**
     * 活动来源  2-流量引导页
     */
    public static final int REQ_ACT_SOURCE_FLOW = 2;
    /**
     * 活动来源 4-活动链接
     */
    public static final int REQ_ACT_SOURCE_URL = 4;
    /**
     * 来源  20-游戏
     */
    public static final int REQ_GAME_SOURCE = 20;
    /**
     * 来源  21-游戏大厅
     */
    public static final int REQ_GAME_HALL = 21;
    /**
     * 活动来源  2-流量引导页 主会场
     */
    public static final String REQ_ACT_SOURCE_FLOW_MINE = "主会场";
    private static final long serialVersionUID = -5825488905457993225L;
    /**
     * ID
     */
    private Long id;

    /**
     * 类型
     */
    private Integer type;

    /**
     * 活动标题
     */
    private String name;

    /**
     * 活动来源 0-兑吧活动 1-推啊活动 2-流量引导页
     */
    private Integer source;

    /**
     * 活动标签
     */
    private String tag;

    /**
     * 活动皮肤
     */
    private String subType;

    private Integer overseas;

    /**
     * 活动链接名称
     */
    private String  activityName;

    /**
     * 活动链接url
     */
    private String  activityUrl;
    /**
     * name.
     *
     * @return the name
     * @since JDK 1.6
     */
    public String getName() {
        return name;
    }

    /**
     * name.
     *
     * @param name the name to set
     * @since JDK 1.6
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * id.
     *
     * @return the id
     * @since JDK 1.6
     */
    public Long getId() {
        return id;
    }

    /**
     * id.
     *
     * @param id the id to set
     * @since JDK 1.6
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * type.
     *
     * @return the type
     * @since JDK 1.6
     */
    public Integer getType() {
        return type;
    }

    /**
     * type.
     *
     * @param type the type to set
     * @since JDK 1.6
     */
    public void setType(Integer type) {
        this.type = type;
    }

    /**
     * source.
     *
     * @return the source
     * @since JDK 1.6
     */
    public Integer getSource() {
        return source;
    }

    /**
     * source.
     *
     * @param source the source to set
     * @since JDK 1.6
     */
    public void setSource(Integer source) {
        this.source = source;
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public Integer getOverseas() {
        return overseas;
    }

    public void setOverseas(Integer overseas) {
        this.overseas = overseas;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public String getActivityUrl() {
        return activityUrl;
    }

    public void setActivityUrl(String activityUrl) {
        this.activityUrl = activityUrl;
    }
}

==> ssp-center-api-0.7.55-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ReqIdAndType.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;

/**
 * 公用查询类
 *
 * @author xuyenan
 * @createTime 2016/10/31
 */
public class ReqIdAndType implements Serializable {

    /**
     * 活动来源 0-兑吧
     */
    public static final int REQ_ACT_SOURCE_DUIBA = 0;
    /**
     * 活动来源 1-推啊
     */
    public static final int REQ_ACT_SOURCE_TUIA = 1;
    /**
     * 活动来源  2-流量引导页
     */
    public static final int REQ_ACT_SOURCE_FLOW = 2;
    /**
     * 活动来源 4-活动链接
     */
    public static final int REQ_ACT_SOURCE_URL = 4;
    /**
     * 来源  20-游戏
     */
    public static final int REQ_GAME_SOURCE = 20;
    /**
     * 来源  21-游戏大厅
     */
    public static final int REQ_GAME_HALL = 21;
    /**
     * 活动来源  2-流量引导页 主会场
     */
    public static final String REQ_ACT_SOURCE_FLOW_MINE = "主会场";
    private static final long serialVersionUID = -5825488905457993225L;
    /**
     * ID
     */
    private Long id;

    /**
     * 类型
     */
    private Integer type;

    /**
     * 活动标题
     */
    private String name;

    /**
     * 活动来源 0-兑吧活动 1-推啊活动 2-流量引导页
     */
    private Integer source;

    /**
     * 活动标签
     */
    private String tag;

    /**
     * 活动皮肤
     */
    private String subType;

    private Integer overseas;

    /**
     * 活动链接名称
     */
    private String  activityName;

    /**
     * 活动链接url
     */
    private String  activityUrl;

    /**
     * 活动二级类型，区分自定义,直投页，原生
     */
    private Integer activitySecondType;
    /**
     * name.
     *
     * @return the name
     * @since JDK 1.6
     */
    public String getName() {
        return name;
    }

    /**
     * name.
     *
     * @param name the name to set
     * @since JDK 1.6
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * id.
     *
     * @return the id
     * @since JDK 1.6
     */
    public Long getId() {
        return id;
    }

    /**
     * id.
     *
     * @param id the id to set
     * @since JDK 1.6
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * type.
     *
     * @return the type
     * @since JDK 1.6
     */
    public Integer getType() {
        return type;
    }

    /**
     * type.
     *
     * @param type the type to set
     * @since JDK 1.6
     */
    public void setType(Integer type) {
        this.type = type;
    }

    /**
     * source.
     *
     * @return the source
     * @since JDK 1.6
     */
    public Integer getSource() {
        return source;
    }

    /**
     * source.
     *
     * @param source the source to set
     * @since JDK 1.6
     */
    public void setSource(Integer source) {
        this.source = source;
    }

    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public Integer getOverseas() {
        return overseas;
    }

    public void setOverseas(Integer overseas) {
        this.overseas = overseas;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public String getActivityUrl() {
        return activityUrl;
    }

    public void setActivityUrl(String activityUrl) {
        this.activityUrl = activityUrl;
    }

    public Integer getActivitySecondType() {
        return activitySecondType;
    }

    public void setActivitySecondType(Integer activitySecondType) {
        this.activitySecondType = activitySecondType;
    }
}
